==> kvpnc_0.8.5.1.orig.tar.gz: kvpnc-0.8.5.1/src/profilenetworkvirtualipoptions.cpp <==
/***************************************************************************
 *   Copyright (C) 2004 by Christoph Thielecke                             *
 *   crissi99@gmx.de                                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "profilenetworkvirtualipoptions.h"

#include <qcheckbox.h>
#include <klineedit.h>

ProfileNetworkVirtualIpOptions::ProfileNetworkVirtualIpOptions(QWidget *parent)
		: ProfileNetworkVirtualIpOptionsBase(parent)
{}


ProfileNetworkVirtualIpOptions::~ProfileNetworkVirtualIpOptions()
{}

void ProfileNetworkVirtualIpOptions::useVirtualIpAddressToggled(bool)
{
	if (UseVirtualIPCheckBox->isChecked()){
		LocalVirtualIpEdit->setEnabled( TRUE );
		RemoteVirtualIpLineEdit->setEnabled( TRUE );
	}
	else {
		LocalVirtualIpEdit->setEnabled( FALSE );
		RemoteVirtualIpLineEdit->setEnabled( FALSE );
	}
}

==> kvpnc_0.9.0.orig.tar.gz: kvpnc-0.9.0.orig/src/profilenetworkvirtualipoptions.cpp <==
/***************************************************************************
 *   Copyright (C) 2004 by Christoph Thielecke                             *
 *   crissi99@gmx.de                                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "profilenetworkvirtualipoptions.h"

#include <qcheckbox.h>
#include <qlabel.h>
#include <klineedit.h>

ProfileNetworkVirtualIpOptions::ProfileNetworkVirtualIpOptions(QWidget *parent)
		: ProfileNetworkVirtualIpOptionsBase(parent)
{}


ProfileNetworkVirtualIpOptions::~ProfileNetworkVirtualIpOptions()
{}

void ProfileNetworkVirtualIpOptions::useVirtualIpAddressToggled(bool)
{
	if (UseVirtualIPCheckBox->isChecked()){
		LocalVirtualIpEdit->setEnabled( TRUE );
		LabelLocalVirtualIp->setEnabled( TRUE );
		RemoteVirtualIpLineEdit->setEnabled( TRUE );
		LabelRemoteVirtualIp->setEnabled( TRUE );
	}
	else {
		LocalVirtualIpEdit->setEnabled( FALSE );
		LabelLocalVirtualIp->setEnabled( FALSE );
		RemoteVirtualIpLineEdit->setEnabled( FALSE );
		LabelRemoteVirtualIp->setEnabled( FALSE );
	}
}
